@@ -1,6 +1,6 @@
 // -*- c++ -*-
 
-/* $Id: signalproxy_connectionnode.cc 137 2004-10-07 16:02:01Z philipl $ */
+/* $Id: signalproxy_connectionnode.cc,v 1.5 2004/07/10 06:35:15 murrayc Exp $ */
 
 /* signalproxy_connectionnode.cc
  *
@@ -68,6 +68,8 @@ void* SignalProxyConnectionNode::notify(void* data)
       g_signal_handler_disconnect(o, connection_id);
     }
   }
+  else if(conn && !conn->object_)
+    g_warning("SignalProxyConnectionNode::notify(): called without gobject");
 
   return 0; // apparently unused in libsigc++
 }
